def sign(x: int) -> int:
    if x != 0:
        return 1 if x > 0 else -1
    return 0
